
# Type: example


usage example and description

URI: [meta:Example](https://w3id.org/biolink/biolinkml/meta/Example)


![img](http://yuml.me/diagram/nofunky;dir:TB/class/[Element]++-%20examples%200..*>[Example&#124;value:string%20%3F;description:string%20%3F])

## Referenced by class

 *  **[Element](Element.md)** *[examples](examples.md)*  <sub>0..*</sub>  **[Example](Example.md)**

## Attributes


### Own

 * [value](value.md)  <sub>OPT</sub>
    * Description: example value
    * range: [String](types/String.md)
 * [example➞description](value_description.md)  <sub>OPT</sub>
    * Description: description of what the value is doing
    * range: [String](types/String.md)

### Domain for slot:

 * [value](value.md)  <sub>OPT</sub>
    * Description: example value
    * range: [String](types/String.md)
 * [example➞description](value_description.md)  <sub>OPT</sub>
    * Description: description of what the value is doing
    * range: [String](types/String.md)
